@@ -1,7 +1,7 @@
 package Test::Starch;
 use 5.008001;
 use strictures 2;
-our $VERSION = '0.11';
+our $VERSION = '0.13';
 
 =head1 NAME
 
@@ -9,7 +9,8 @@ Test::Starch - Test core features of starch.
 
 =head1 SYNOPSIS
 
-    use Test::More;
+    use Test2::V0;
+    use Test::Starch;
     
     my $tester = Test::Starch->new(
         plugins => [ ... ],
@@ -45,10 +46,11 @@ if the C<store> argument is not passed it will defailt to a Memory store.
 use Types::Standard -types;
 use Types::Common::String -types;
 
-use Starch;
-use Starch::Manager;
 use Test2::V0;
 
+use Test2::Require::Module 'Starch';
+BEGIN { require Starch }
+
 use Moo;
 use namespace::clean;
 
@@ -59,14 +61,14 @@ around BUILDARGS => sub{
     my $args = $class->$orig( @_ );
 
     return {
-        args => {
+        _manager_args => {
             store => { class=>'::Memory' },
             %$args,
         },
     };
 };
 
-has args => (
+has _manager_args => (
     is       => 'ro',
     isa      => HashRef,
     required => 1,
@@ -88,7 +90,7 @@ sub new_manager {
     my $extra_args = Starch::Manager->BUILDARGS( @_ );
 
     return Starch->new(
-        %{ $self->args() },
+        %{ $self->_manager_args() },
         %{ $extra_args },
     );
 }
@@ -109,7 +111,7 @@ sub test {
 
 =head2 test_manager
 
-Tests L<Starch>.
+Tests L<Starch::Manager>.
 
 =cut
 
@@ -480,9 +482,17 @@ sub test_store {
 1;
 __END__
 
-=head1 AUTHORS AND LICENSE
+=head1 SUPPORT
 
-See L<Starch/AUTHOR>, L<Starch/CONTRIBUTORS>, and L<Starch/LICENSE>.
+See L<Starch/SUPPORT>.
+
+=head1 AUTHORS
+
+See L<Starch/AUTHORS>.
+
+=head1 LICENSE
+
+See L<Starch/LICENSE>.
 
 =cut
 
